#!/bin/sh -e

. ../../common-script.sh

# Search for possible Diablo II Resurrected folder locations
printf "%b\n" "${YELLOW}Searching for Diablo II Resurrected folders...${RC}"
possible_paths=$(find $HOME -type d -path "*/drive_c/Program Files (x86)/Diablo II Resurrected" 2>/dev/null)

if [ -z "$possible_paths" ]; then
    printf "%b\n" "${RED}Error: No Diablo II Resurrected folders found.${RC}"
    exit 1
fi

# Display possible paths and allow selection
printf "%b\n" "${YELLOW}Possible Diablo II Resurrected folder locations:${RC}"
mapfile -t paths_array <<< "$possible_paths"
selected=0
total=${#paths_array[@]}

print_menu() {
    clear
    local max_display=$((total < 10 ? total : 10))
    local start=$((selected - max_display/2))
    if ((start < 0)); then start=0; fi
    if ((start + max_display > total)); then start=$((total - max_display)); fi
    if ((start < 0)); then start=0; fi
    
    printf "%b\n" "${YELLOW}Please select the Diablo II: Resurrected installation path:${RC}"
    for i in $(seq 0 $((max_display - 1))); do
        if ((i + start >= total)); then break; fi
        if [ $((i + start)) -eq $selected ]; then
            echo "> ${paths_array[$((i + start))]}"
        else
            echo "  ${paths_array[$((i + start))]}"
        fi
    done
}

select_path() {
    local last_selected=-1

    while true; do
        if [ $last_selected -ne $selected ]; then
            print_menu
            last_selected=$selected
        fi

        read -rsn1 key
        case "$key" in
            $'\x1B')  # ESC key
                read -rsn2 key
                case "$key" in
                    '[A' | 'k')
                        if ((selected > 0)); then
                            ((selected--))
                        fi
                        ;;
                    '[B' | 'j')
                        if ((selected < total - 1)); then
                            ((selected++))
                        fi
                        ;;
                esac
                ;;
            '')  # Enter key
                d2r_path="${paths_array[$selected]}"
                break
                ;;
        esac
    done

    clear  # Clear the screen after selection
}

# Use the select_path function
select_path

# Validate the path
if [ ! -d "$d2r_path" ]; then
    printf "%b\n" "${RED}Error: The specified path does not exist.${RC}"
    exit 1
fi

# Create the mods folder if it doesn't exist
mods_path="$d2r_path/mods"
mkdir -p "$mods_path"

# Download the latest release
printf "%b\n" "${YELLOW}Downloading the latest loot filter...${RC}"
curl -sSLo /tmp/lootfilter.zip https://github.com/ChrisTitusTech/d2r-loot-filter/releases/latest/download/lootfilter.zip

# Extract the contents to the mods folder
printf "%b\n" "${YELLOW}Extracting loot filter to $mods_path...${RC}"
unzip -q -o /tmp/lootfilter.zip -d "$mods_path"

# Clean up
rm /tmp/lootfilter.zip

printf "%b\n" "${GREEN}Loot filter installed successfully in $mods_path${RC}"

printf "\nTo complete the setup, please follow these steps to add launch options in Battle.net:\n"
printf "1. Open the Battle.net launcher\n"
printf "2. Select Diablo II: Resurrected\n"
printf "3. Click the gear icon next to the 'Play' button\n"
printf "4. Select 'Game Settings'\n"
printf "5. In the 'Additional command line arguments' field, enter: -mod lootfilter -txt\n"
printf "6. Click 'Done' to save the changes\n"
printf "\nAfter completing these steps, launch Diablo II: Resurrected through Battle.net to use the loot filter.\n"